# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/types/action.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/types/action.proto',
  package='iotextypes',
  syntax='proto3',
  serialized_options=b'\n\"com.github.iotexproject.grpc.typesP\001Z5github.com/iotexproject/iotex-proto/golang/iotextypes',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18proto/types/action.proto\x12\niotextypes\">\n\x08Transfer\x12\x0e\n\x06\x61mount\x18\x01 \x01(\t\x12\x11\n\trecipient\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"R\n\tCandidate\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05votes\x18\x02 \x01(\x0c\x12\x0e\n\x06pubKey\x18\x03 \x01(\x0c\x12\x15\n\rrewardAddress\x18\x04 \x01(\t\":\n\rCandidateList\x12)\n\ncandidates\x18\x01 \x03(\x0b\x32\x15.iotextypes.Candidate\"N\n\rPutPollResult\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12-\n\ncandidates\x18\x02 \x01(\x0b\x32\x19.iotextypes.CandidateList\";\n\tExecution\x12\x0e\n\x06\x61mount\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"v\n\x0bStakeCreate\x12\x15\n\rcandidateName\x18\x01 \x01(\t\x12\x14\n\x0cstakedAmount\x18\x02 \x01(\t\x12\x16\n\x0estakedDuration\x18\x03 \x01(\r\x12\x11\n\tautoStake\x18\x04 \x01(\x08\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\"4\n\x0cStakeReclaim\x12\x13\n\x0b\x62ucketIndex\x18\x01 \x01(\x04\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"G\n\x0fStakeAddDeposit\x12\x13\n\x0b\x62ucketIndex\x18\x01 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"_\n\x0cStakeRestake\x12\x13\n\x0b\x62ucketIndex\x18\x01 \x01(\x04\x12\x16\n\x0estakedDuration\x18\x02 \x01(\r\x12\x11\n\tautoStake\x18\x03 \x01(\x08\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"S\n\x14StakeChangeCandidate\x12\x13\n\x0b\x62ucketIndex\x18\x01 \x01(\x04\x12\x15\n\rcandidateName\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"T\n\x16StakeTransferOwnership\x12\x13\n\x0b\x62ucketIndex\x18\x01 \x01(\x04\x12\x14\n\x0cvoterAddress\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"R\n\x12\x43\x61ndidateBasicInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0foperatorAddress\x18\x02 \x01(\t\x12\x15\n\rrewardAddress\x18\x03 \x01(\t\"\xae\x01\n\x11\x43\x61ndidateRegister\x12\x31\n\tcandidate\x18\x01 \x01(\x0b\x32\x1e.iotextypes.CandidateBasicInfo\x12\x14\n\x0cstakedAmount\x18\x02 \x01(\t\x12\x16\n\x0estakedDuration\x18\x03 \x01(\r\x12\x11\n\tautoStake\x18\x04 \x01(\x08\x12\x14\n\x0cownerAddress\x18\x05 \x01(\t\x12\x0f\n\x07payload\x18\x06 \x01(\x0c\"\x84\x01\n\rStartSubChain\x12\x0f\n\x07\x63hainID\x18\x01 \x01(\r\x12\x17\n\x0fsecurityDeposit\x18\x02 \x01(\t\x12\x18\n\x10operationDeposit\x18\x03 \x01(\t\x12\x13\n\x0bstartHeight\x18\x04 \x01(\x04\x12\x1a\n\x12parentHeightOffset\x18\x05 \x01(\x04\"L\n\x0cStopSubChain\x12\x0f\n\x07\x63hainID\x18\x01 \x01(\r\x12\x12\n\nstopHeight\x18\x02 \x01(\x04\x12\x17\n\x0fsubChainAddress\x18\x03 \x01(\t\")\n\nMerkleRoot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"Z\n\x08PutBlock\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12%\n\x05roots\x18\x03 \x03(\x0b\x32\x16.iotextypes.MerkleRoot\"C\n\rCreateDeposit\x12\x0f\n\x07\x63hainID\x18\x01 \x01(\r\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\"A\n\rSettleDeposit\x12\x0e\n\x06\x61mount\x18\x01 \x01(\t\x12\x11\n\trecipient\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x04\"\x11\n\x0f\x43reatePlumChain\"-\n\x12TerminatePlumChain\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\"\x99\x01\n\x0cPlumPutBlock\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x32\n\x05roots\x18\x03 \x03(\x0b\x32#.iotextypes.PlumPutBlock.RootsEntry\x1a,\n\nRootsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"O\n\x11PlumCreateDeposit\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\"\xe2\x01\n\rPlumStartExit\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x18\n\x10previousTransfer\x18\x02 \x01(\x0c\x12\"\n\x1apreviousTransferBlockProof\x18\x03 \x01(\x0c\x12#\n\x1bpreviousTransferBlockHeight\x18\x04 \x01(\x04\x12\x14\n\x0c\x65xitTransfer\x18\x05 \x01(\x0c\x12\x1e\n\x16\x65xitTransferBlockProof\x18\x06 \x01(\x0c\x12\x1f\n\x17\x65xitTransferBlockHeight\x18\x07 \x01(\x04\"\xa2\x01\n\x11PlumChallengeExit\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06\x63oinID\x18\x02 \x01(\x04\x12\x19\n\x11\x63hallengeTransfer\x18\x03 \x01(\x0c\x12#\n\x1b\x63hallengeTransferBlockProof\x18\x04 \x01(\x0c\x12$\n\x1c\x63hallengeTransferBlockHeight\x18\x05 \x01(\x04\"\xc2\x01\n\x19PlumResponseChallengeExit\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06\x63oinID\x18\x02 \x01(\x04\x12\x19\n\x11\x63hallengeTransfer\x18\x03 \x01(\x0c\x12\x18\n\x10responseTransfer\x18\x04 \x01(\x0c\x12\"\n\x1aresponseTransferBlockProof\x18\x05 \x01(\x0c\x12#\n\x1bpreviousTransferBlockHeight\x18\x06 \x01(\x04\";\n\x10PlumFinalizeExit\x12\x17\n\x0fsubChainAddress\x18\x01 \x01(\t\x12\x0e\n\x06\x63oinID\x18\x02 \x01(\x04\"#\n\x11PlumSettleDeposit\x12\x0e\n\x06\x63oinID\x18\x01 \x01(\x04\"V\n\x0cPlumTransfer\x12\x0e\n\x06\x63oinID\x18\x01 \x01(\x04\x12\x14\n\x0c\x64\x65nomination\x18\x02 \x01(\x0c\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x11\n\trecipient\x18\x04 \x01(\t\"\xde\r\n\nActionCore\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\r\n\x05nonce\x18\x02 \x01(\x04\x12\x10\n\x08gasLimit\x18\x03 \x01(\x04\x12\x10\n\x08gasPrice\x18\x04 \x01(\t\x12(\n\x08transfer\x18\n \x01(\x0b\x32\x14.iotextypes.TransferH\x00\x12*\n\texecution\x18\x0c \x01(\x0b\x32\x15.iotextypes.ExecutionH\x00\x12\x32\n\rstartSubChain\x18\r \x01(\x0b\x32\x19.iotextypes.StartSubChainH\x00\x12\x30\n\x0cstopSubChain\x18\x0e \x01(\x0b\x32\x18.iotextypes.StopSubChainH\x00\x12(\n\x08putBlock\x18\x0f \x01(\x0b\x32\x14.iotextypes.PutBlockH\x00\x12\x32\n\rcreateDeposit\x18\x10 \x01(\x0b\x32\x19.iotextypes.CreateDepositH\x00\x12\x32\n\rsettleDeposit\x18\x11 \x01(\x0b\x32\x19.iotextypes.SettleDepositH\x00\x12\x36\n\x0f\x63reatePlumChain\x18\x12 \x01(\x0b\x32\x1b.iotextypes.CreatePlumChainH\x00\x12<\n\x12terminatePlumChain\x18\x13 \x01(\x0b\x32\x1e.iotextypes.TerminatePlumChainH\x00\x12\x30\n\x0cplumPutBlock\x18\x14 \x01(\x0b\x32\x18.iotextypes.PlumPutBlockH\x00\x12:\n\x11plumCreateDeposit\x18\x15 \x01(\x0b\x32\x1d.iotextypes.PlumCreateDepositH\x00\x12\x32\n\rplumStartExit\x18\x16 \x01(\x0b\x32\x19.iotextypes.PlumStartExitH\x00\x12:\n\x11plumChallengeExit\x18\x17 \x01(\x0b\x32\x1d.iotextypes.PlumChallengeExitH\x00\x12J\n\x19plumResponseChallengeExit\x18\x18 \x01(\x0b\x32%.iotextypes.PlumResponseChallengeExitH\x00\x12\x38\n\x10plumFinalizeExit\x18\x19 \x01(\x0b\x32\x1c.iotextypes.PlumFinalizeExitH\x00\x12:\n\x11plumSettleDeposit\x18\x1a \x01(\x0b\x32\x1d.iotextypes.PlumSettleDepositH\x00\x12\x30\n\x0cplumTransfer\x18\x1b \x01(\x0b\x32\x18.iotextypes.PlumTransferH\x00\x12\x44\n\x16\x64\x65positToRewardingFund\x18\x1e \x01(\x0b\x32\".iotextypes.DepositToRewardingFundH\x00\x12\x44\n\x16\x63laimFromRewardingFund\x18\x1f \x01(\x0b\x32\".iotextypes.ClaimFromRewardingFundH\x00\x12.\n\x0bgrantReward\x18  \x01(\x0b\x32\x17.iotextypes.GrantRewardH\x00\x12.\n\x0bstakeCreate\x18( \x01(\x0b\x32\x17.iotextypes.StakeCreateH\x00\x12\x30\n\x0cstakeUnstake\x18) \x01(\x0b\x32\x18.iotextypes.StakeReclaimH\x00\x12\x31\n\rstakeWithdraw\x18* \x01(\x0b\x32\x18.iotextypes.StakeReclaimH\x00\x12\x36\n\x0fstakeAddDeposit\x18+ \x01(\x0b\x32\x1b.iotextypes.StakeAddDepositH\x00\x12\x30\n\x0cstakeRestake\x18, \x01(\x0b\x32\x18.iotextypes.StakeRestakeH\x00\x12@\n\x14stakeChangeCandidate\x18- \x01(\x0b\x32 .iotextypes.StakeChangeCandidateH\x00\x12\x44\n\x16stakeTransferOwnership\x18. \x01(\x0b\x32\".iotextypes.StakeTransferOwnershipH\x00\x12:\n\x11\x63\x61ndidateRegister\x18/ \x01(\x0b\x32\x1d.iotextypes.CandidateRegisterH\x00\x12\x39\n\x0f\x63\x61ndidateUpdate\x18\x30 \x01(\x0b\x32\x1e.iotextypes.CandidateBasicInfoH\x00\x12\x32\n\rputPollResult\x18\x32 \x01(\x0b\x32\x19.iotextypes.PutPollResultH\x00\x42\x08\n\x06\x61\x63tion\"W\n\x06\x41\x63tion\x12$\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x16.iotextypes.ActionCore\x12\x14\n\x0csenderPubKey\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"\x8a\x01\n\x07Receipt\x12\x0e\n\x06status\x18\x01 \x01(\x04\x12\x11\n\tblkHeight\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x63tHash\x18\x03 \x01(\x0c\x12\x13\n\x0bgasConsumed\x18\x04 \x01(\x04\x12\x17\n\x0f\x63ontractAddress\x18\x05 \x01(\t\x12\x1d\n\x04logs\x18\x06 \x03(\x0b\x32\x0f.iotextypes.Log\"o\n\x03Log\x12\x17\n\x0f\x63ontractAddress\x18\x01 \x01(\t\x12\x0e\n\x06topics\x18\x02 \x03(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\tblkHeight\x18\x04 \x01(\x04\x12\x0f\n\x07\x61\x63tHash\x18\x05 \x01(\x0c\x12\r\n\x05index\x18\x06 \x01(\r\"%\n\x04Logs\x12\x1d\n\x04logs\x18\x01 \x03(\x0b\x32\x0f.iotextypes.Log\"7\n\x0b\x45vmTransfer\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x0c\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\n\n\x02to\x18\x03 \x01(\t\"@\n\x0f\x45vmTransferList\x12-\n\x0c\x65vmTransfers\x18\x01 \x03(\x0b\x32\x17.iotextypes.EvmTransfer\"o\n\x11\x41\x63tionEvmTransfer\x12\x12\n\nactionHash\x18\x01 \x01(\x0c\x12\x17\n\x0fnumEvmTransfers\x18\x02 \x01(\x04\x12-\n\x0c\x65vmTransfers\x18\x03 \x03(\x0b\x32\x17.iotextypes.EvmTransfer\"{\n\x10\x42lockEvmTransfer\x12\x13\n\x0b\x62lockHeight\x18\x01 \x01(\x04\x12\x17\n\x0fnumEvmTransfers\x18\x02 \x01(\x04\x12\x39\n\x12\x61\x63tionEvmTransfers\x18\x03 \x03(\x0b\x32\x1d.iotextypes.ActionEvmTransfer\"6\n\x16\x44\x65positToRewardingFund\x12\x0e\n\x06\x61mount\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"6\n\x16\x43laimFromRewardingFund\x12\x0e\n\x06\x61mount\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"C\n\x0bGrantReward\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.iotextypes.RewardType\x12\x0e\n\x06height\x18\x02 \x01(\x04*.\n\nRewardType\x12\x0f\n\x0b\x42lockReward\x10\x00\x12\x0f\n\x0b\x45pochReward\x10\x01\x42]\n\"com.github.iotexproject.grpc.typesP\x01Z5github.com/iotexproject/iotex-proto/golang/iotextypesb\x06proto3'
)

_REWARDTYPE = _descriptor.EnumDescriptor(
  name='RewardType',
  full_name='iotextypes.RewardType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BlockReward', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EpochReward', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5414,
  serialized_end=5460,
)
_sym_db.RegisterEnumDescriptor(_REWARDTYPE)

RewardType = enum_type_wrapper.EnumTypeWrapper(_REWARDTYPE)
BlockReward = 0
EpochReward = 1



_TRANSFER = _descriptor.Descriptor(
  name='Transfer',
  full_name='iotextypes.Transfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.Transfer.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='iotextypes.Transfer.recipient', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.Transfer.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=102,
)


_CANDIDATE = _descriptor.Descriptor(
  name='Candidate',
  full_name='iotextypes.Candidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotextypes.Candidate.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='iotextypes.Candidate.votes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pubKey', full_name='iotextypes.Candidate.pubKey', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewardAddress', full_name='iotextypes.Candidate.rewardAddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=186,
)


_CANDIDATELIST = _descriptor.Descriptor(
  name='CandidateList',
  full_name='iotextypes.CandidateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidates', full_name='iotextypes.CandidateList.candidates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=246,
)


_PUTPOLLRESULT = _descriptor.Descriptor(
  name='PutPollResult',
  full_name='iotextypes.PutPollResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.PutPollResult.height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidates', full_name='iotextypes.PutPollResult.candidates', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=326,
)


_EXECUTION = _descriptor.Descriptor(
  name='Execution',
  full_name='iotextypes.Execution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.Execution.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='iotextypes.Execution.contract', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='iotextypes.Execution.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=387,
)


_STAKECREATE = _descriptor.Descriptor(
  name='StakeCreate',
  full_name='iotextypes.StakeCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidateName', full_name='iotextypes.StakeCreate.candidateName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakedAmount', full_name='iotextypes.StakeCreate.stakedAmount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakedDuration', full_name='iotextypes.StakeCreate.stakedDuration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoStake', full_name='iotextypes.StakeCreate.autoStake', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeCreate.payload', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=507,
)


_STAKERECLAIM = _descriptor.Descriptor(
  name='StakeReclaim',
  full_name='iotextypes.StakeReclaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketIndex', full_name='iotextypes.StakeReclaim.bucketIndex', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeReclaim.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=561,
)


_STAKEADDDEPOSIT = _descriptor.Descriptor(
  name='StakeAddDeposit',
  full_name='iotextypes.StakeAddDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketIndex', full_name='iotextypes.StakeAddDeposit.bucketIndex', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.StakeAddDeposit.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeAddDeposit.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=634,
)


_STAKERESTAKE = _descriptor.Descriptor(
  name='StakeRestake',
  full_name='iotextypes.StakeRestake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketIndex', full_name='iotextypes.StakeRestake.bucketIndex', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakedDuration', full_name='iotextypes.StakeRestake.stakedDuration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoStake', full_name='iotextypes.StakeRestake.autoStake', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeRestake.payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=731,
)


_STAKECHANGECANDIDATE = _descriptor.Descriptor(
  name='StakeChangeCandidate',
  full_name='iotextypes.StakeChangeCandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketIndex', full_name='iotextypes.StakeChangeCandidate.bucketIndex', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidateName', full_name='iotextypes.StakeChangeCandidate.candidateName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeChangeCandidate.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=816,
)


_STAKETRANSFEROWNERSHIP = _descriptor.Descriptor(
  name='StakeTransferOwnership',
  full_name='iotextypes.StakeTransferOwnership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketIndex', full_name='iotextypes.StakeTransferOwnership.bucketIndex', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voterAddress', full_name='iotextypes.StakeTransferOwnership.voterAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.StakeTransferOwnership.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=902,
)


_CANDIDATEBASICINFO = _descriptor.Descriptor(
  name='CandidateBasicInfo',
  full_name='iotextypes.CandidateBasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='iotextypes.CandidateBasicInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operatorAddress', full_name='iotextypes.CandidateBasicInfo.operatorAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewardAddress', full_name='iotextypes.CandidateBasicInfo.rewardAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=986,
)


_CANDIDATEREGISTER = _descriptor.Descriptor(
  name='CandidateRegister',
  full_name='iotextypes.CandidateRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='iotextypes.CandidateRegister.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakedAmount', full_name='iotextypes.CandidateRegister.stakedAmount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakedDuration', full_name='iotextypes.CandidateRegister.stakedDuration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoStake', full_name='iotextypes.CandidateRegister.autoStake', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ownerAddress', full_name='iotextypes.CandidateRegister.ownerAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='iotextypes.CandidateRegister.payload', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1163,
)


_STARTSUBCHAIN = _descriptor.Descriptor(
  name='StartSubChain',
  full_name='iotextypes.StartSubChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chainID', full_name='iotextypes.StartSubChain.chainID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='securityDeposit', full_name='iotextypes.StartSubChain.securityDeposit', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operationDeposit', full_name='iotextypes.StartSubChain.operationDeposit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startHeight', full_name='iotextypes.StartSubChain.startHeight', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parentHeightOffset', full_name='iotextypes.StartSubChain.parentHeightOffset', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1166,
  serialized_end=1298,
)


_STOPSUBCHAIN = _descriptor.Descriptor(
  name='StopSubChain',
  full_name='iotextypes.StopSubChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chainID', full_name='iotextypes.StopSubChain.chainID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopHeight', full_name='iotextypes.StopSubChain.stopHeight', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.StopSubChain.subChainAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1300,
  serialized_end=1376,
)


_MERKLEROOT = _descriptor.Descriptor(
  name='MerkleRoot',
  full_name='iotextypes.MerkleRoot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='iotextypes.MerkleRoot.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='iotextypes.MerkleRoot.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1419,
)


_PUTBLOCK = _descriptor.Descriptor(
  name='PutBlock',
  full_name='iotextypes.PutBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PutBlock.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.PutBlock.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roots', full_name='iotextypes.PutBlock.roots', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1421,
  serialized_end=1511,
)


_CREATEDEPOSIT = _descriptor.Descriptor(
  name='CreateDeposit',
  full_name='iotextypes.CreateDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chainID', full_name='iotextypes.CreateDeposit.chainID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.CreateDeposit.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='iotextypes.CreateDeposit.recipient', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1513,
  serialized_end=1580,
)


_SETTLEDEPOSIT = _descriptor.Descriptor(
  name='SettleDeposit',
  full_name='iotextypes.SettleDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.SettleDeposit.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='iotextypes.SettleDeposit.recipient', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='iotextypes.SettleDeposit.index', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1647,
)


_CREATEPLUMCHAIN = _descriptor.Descriptor(
  name='CreatePlumChain',
  full_name='iotextypes.CreatePlumChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1649,
  serialized_end=1666,
)


_TERMINATEPLUMCHAIN = _descriptor.Descriptor(
  name='TerminatePlumChain',
  full_name='iotextypes.TerminatePlumChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.TerminatePlumChain.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1713,
)


_PLUMPUTBLOCK_ROOTSENTRY = _descriptor.Descriptor(
  name='RootsEntry',
  full_name='iotextypes.PlumPutBlock.RootsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='iotextypes.PlumPutBlock.RootsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='iotextypes.PlumPutBlock.RootsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1825,
  serialized_end=1869,
)

_PLUMPUTBLOCK = _descriptor.Descriptor(
  name='PlumPutBlock',
  full_name='iotextypes.PlumPutBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumPutBlock.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.PlumPutBlock.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roots', full_name='iotextypes.PlumPutBlock.roots', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLUMPUTBLOCK_ROOTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1869,
)


_PLUMCREATEDEPOSIT = _descriptor.Descriptor(
  name='PlumCreateDeposit',
  full_name='iotextypes.PlumCreateDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumCreateDeposit.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.PlumCreateDeposit.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='iotextypes.PlumCreateDeposit.recipient', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1950,
)


_PLUMSTARTEXIT = _descriptor.Descriptor(
  name='PlumStartExit',
  full_name='iotextypes.PlumStartExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumStartExit.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previousTransfer', full_name='iotextypes.PlumStartExit.previousTransfer', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previousTransferBlockProof', full_name='iotextypes.PlumStartExit.previousTransferBlockProof', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previousTransferBlockHeight', full_name='iotextypes.PlumStartExit.previousTransferBlockHeight', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exitTransfer', full_name='iotextypes.PlumStartExit.exitTransfer', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exitTransferBlockProof', full_name='iotextypes.PlumStartExit.exitTransferBlockProof', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exitTransferBlockHeight', full_name='iotextypes.PlumStartExit.exitTransferBlockHeight', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1953,
  serialized_end=2179,
)


_PLUMCHALLENGEEXIT = _descriptor.Descriptor(
  name='PlumChallengeExit',
  full_name='iotextypes.PlumChallengeExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumChallengeExit.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coinID', full_name='iotextypes.PlumChallengeExit.coinID', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challengeTransfer', full_name='iotextypes.PlumChallengeExit.challengeTransfer', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challengeTransferBlockProof', full_name='iotextypes.PlumChallengeExit.challengeTransferBlockProof', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challengeTransferBlockHeight', full_name='iotextypes.PlumChallengeExit.challengeTransferBlockHeight', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2182,
  serialized_end=2344,
)


_PLUMRESPONSECHALLENGEEXIT = _descriptor.Descriptor(
  name='PlumResponseChallengeExit',
  full_name='iotextypes.PlumResponseChallengeExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumResponseChallengeExit.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coinID', full_name='iotextypes.PlumResponseChallengeExit.coinID', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challengeTransfer', full_name='iotextypes.PlumResponseChallengeExit.challengeTransfer', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='responseTransfer', full_name='iotextypes.PlumResponseChallengeExit.responseTransfer', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='responseTransferBlockProof', full_name='iotextypes.PlumResponseChallengeExit.responseTransferBlockProof', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previousTransferBlockHeight', full_name='iotextypes.PlumResponseChallengeExit.previousTransferBlockHeight', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2347,
  serialized_end=2541,
)


_PLUMFINALIZEEXIT = _descriptor.Descriptor(
  name='PlumFinalizeExit',
  full_name='iotextypes.PlumFinalizeExit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subChainAddress', full_name='iotextypes.PlumFinalizeExit.subChainAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coinID', full_name='iotextypes.PlumFinalizeExit.coinID', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2543,
  serialized_end=2602,
)


_PLUMSETTLEDEPOSIT = _descriptor.Descriptor(
  name='PlumSettleDeposit',
  full_name='iotextypes.PlumSettleDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='coinID', full_name='iotextypes.PlumSettleDeposit.coinID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2604,
  serialized_end=2639,
)


_PLUMTRANSFER = _descriptor.Descriptor(
  name='PlumTransfer',
  full_name='iotextypes.PlumTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='coinID', full_name='iotextypes.PlumTransfer.coinID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denomination', full_name='iotextypes.PlumTransfer.denomination', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='iotextypes.PlumTransfer.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipient', full_name='iotextypes.PlumTransfer.recipient', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2641,
  serialized_end=2727,
)


_ACTIONCORE = _descriptor.Descriptor(
  name='ActionCore',
  full_name='iotextypes.ActionCore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='iotextypes.ActionCore.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='iotextypes.ActionCore.nonce', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasLimit', full_name='iotextypes.ActionCore.gasLimit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasPrice', full_name='iotextypes.ActionCore.gasPrice', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer', full_name='iotextypes.ActionCore.transfer', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution', full_name='iotextypes.ActionCore.execution', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startSubChain', full_name='iotextypes.ActionCore.startSubChain', index=6,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopSubChain', full_name='iotextypes.ActionCore.stopSubChain', index=7,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='putBlock', full_name='iotextypes.ActionCore.putBlock', index=8,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createDeposit', full_name='iotextypes.ActionCore.createDeposit', index=9,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settleDeposit', full_name='iotextypes.ActionCore.settleDeposit', index=10,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createPlumChain', full_name='iotextypes.ActionCore.createPlumChain', index=11,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminatePlumChain', full_name='iotextypes.ActionCore.terminatePlumChain', index=12,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumPutBlock', full_name='iotextypes.ActionCore.plumPutBlock', index=13,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumCreateDeposit', full_name='iotextypes.ActionCore.plumCreateDeposit', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumStartExit', full_name='iotextypes.ActionCore.plumStartExit', index=15,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumChallengeExit', full_name='iotextypes.ActionCore.plumChallengeExit', index=16,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumResponseChallengeExit', full_name='iotextypes.ActionCore.plumResponseChallengeExit', index=17,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumFinalizeExit', full_name='iotextypes.ActionCore.plumFinalizeExit', index=18,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumSettleDeposit', full_name='iotextypes.ActionCore.plumSettleDeposit', index=19,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plumTransfer', full_name='iotextypes.ActionCore.plumTransfer', index=20,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depositToRewardingFund', full_name='iotextypes.ActionCore.depositToRewardingFund', index=21,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimFromRewardingFund', full_name='iotextypes.ActionCore.claimFromRewardingFund', index=22,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantReward', full_name='iotextypes.ActionCore.grantReward', index=23,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeCreate', full_name='iotextypes.ActionCore.stakeCreate', index=24,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeUnstake', full_name='iotextypes.ActionCore.stakeUnstake', index=25,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeWithdraw', full_name='iotextypes.ActionCore.stakeWithdraw', index=26,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeAddDeposit', full_name='iotextypes.ActionCore.stakeAddDeposit', index=27,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeRestake', full_name='iotextypes.ActionCore.stakeRestake', index=28,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeChangeCandidate', full_name='iotextypes.ActionCore.stakeChangeCandidate', index=29,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stakeTransferOwnership', full_name='iotextypes.ActionCore.stakeTransferOwnership', index=30,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidateRegister', full_name='iotextypes.ActionCore.candidateRegister', index=31,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidateUpdate', full_name='iotextypes.ActionCore.candidateUpdate', index=32,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='putPollResult', full_name='iotextypes.ActionCore.putPollResult', index=33,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='iotextypes.ActionCore.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2730,
  serialized_end=4488,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='iotextypes.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='core', full_name='iotextypes.Action.core', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='senderPubKey', full_name='iotextypes.Action.senderPubKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='iotextypes.Action.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4490,
  serialized_end=4577,
)


_RECEIPT = _descriptor.Descriptor(
  name='Receipt',
  full_name='iotextypes.Receipt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='iotextypes.Receipt.status', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkHeight', full_name='iotextypes.Receipt.blkHeight', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actHash', full_name='iotextypes.Receipt.actHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasConsumed', full_name='iotextypes.Receipt.gasConsumed', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractAddress', full_name='iotextypes.Receipt.contractAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logs', full_name='iotextypes.Receipt.logs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4580,
  serialized_end=4718,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='iotextypes.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contractAddress', full_name='iotextypes.Log.contractAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='iotextypes.Log.topics', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='iotextypes.Log.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blkHeight', full_name='iotextypes.Log.blkHeight', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actHash', full_name='iotextypes.Log.actHash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='iotextypes.Log.index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4720,
  serialized_end=4831,
)


_LOGS = _descriptor.Descriptor(
  name='Logs',
  full_name='iotextypes.Logs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='iotextypes.Logs.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4833,
  serialized_end=4870,
)


_EVMTRANSFER = _descriptor.Descriptor(
  name='EvmTransfer',
  full_name='iotextypes.EvmTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.EvmTransfer.amount', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='iotextypes.EvmTransfer.from', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='iotextypes.EvmTransfer.to', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4872,
  serialized_end=4927,
)


_EVMTRANSFERLIST = _descriptor.Descriptor(
  name='EvmTransferList',
  full_name='iotextypes.EvmTransferList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='evmTransfers', full_name='iotextypes.EvmTransferList.evmTransfers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4929,
  serialized_end=4993,
)


_ACTIONEVMTRANSFER = _descriptor.Descriptor(
  name='ActionEvmTransfer',
  full_name='iotextypes.ActionEvmTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionHash', full_name='iotextypes.ActionEvmTransfer.actionHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numEvmTransfers', full_name='iotextypes.ActionEvmTransfer.numEvmTransfers', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evmTransfers', full_name='iotextypes.ActionEvmTransfer.evmTransfers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4995,
  serialized_end=5106,
)


_BLOCKEVMTRANSFER = _descriptor.Descriptor(
  name='BlockEvmTransfer',
  full_name='iotextypes.BlockEvmTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHeight', full_name='iotextypes.BlockEvmTransfer.blockHeight', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numEvmTransfers', full_name='iotextypes.BlockEvmTransfer.numEvmTransfers', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionEvmTransfers', full_name='iotextypes.BlockEvmTransfer.actionEvmTransfers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5108,
  serialized_end=5231,
)


_DEPOSITTOREWARDINGFUND = _descriptor.Descriptor(
  name='DepositToRewardingFund',
  full_name='iotextypes.DepositToRewardingFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.DepositToRewardingFund.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='iotextypes.DepositToRewardingFund.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5233,
  serialized_end=5287,
)


_CLAIMFROMREWARDINGFUND = _descriptor.Descriptor(
  name='ClaimFromRewardingFund',
  full_name='iotextypes.ClaimFromRewardingFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='iotextypes.ClaimFromRewardingFund.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='iotextypes.ClaimFromRewardingFund.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5289,
  serialized_end=5343,
)


_GRANTREWARD = _descriptor.Descriptor(
  name='GrantReward',
  full_name='iotextypes.GrantReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='iotextypes.GrantReward.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.GrantReward.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5345,
  serialized_end=5412,
)

_CANDIDATELIST.fields_by_name['candidates'].message_type = _CANDIDATE
_PUTPOLLRESULT.fields_by_name['candidates'].message_type = _CANDIDATELIST
_CANDIDATEREGISTER.fields_by_name['candidate'].message_type = _CANDIDATEBASICINFO
_PUTBLOCK.fields_by_name['roots'].message_type = _MERKLEROOT
_PLUMPUTBLOCK_ROOTSENTRY.containing_type = _PLUMPUTBLOCK
_PLUMPUTBLOCK.fields_by_name['roots'].message_type = _PLUMPUTBLOCK_ROOTSENTRY
_ACTIONCORE.fields_by_name['transfer'].message_type = _TRANSFER
_ACTIONCORE.fields_by_name['execution'].message_type = _EXECUTION
_ACTIONCORE.fields_by_name['startSubChain'].message_type = _STARTSUBCHAIN
_ACTIONCORE.fields_by_name['stopSubChain'].message_type = _STOPSUBCHAIN
_ACTIONCORE.fields_by_name['putBlock'].message_type = _PUTBLOCK
_ACTIONCORE.fields_by_name['createDeposit'].message_type = _CREATEDEPOSIT
_ACTIONCORE.fields_by_name['settleDeposit'].message_type = _SETTLEDEPOSIT
_ACTIONCORE.fields_by_name['createPlumChain'].message_type = _CREATEPLUMCHAIN
_ACTIONCORE.fields_by_name['terminatePlumChain'].message_type = _TERMINATEPLUMCHAIN
_ACTIONCORE.fields_by_name['plumPutBlock'].message_type = _PLUMPUTBLOCK
_ACTIONCORE.fields_by_name['plumCreateDeposit'].message_type = _PLUMCREATEDEPOSIT
_ACTIONCORE.fields_by_name['plumStartExit'].message_type = _PLUMSTARTEXIT
_ACTIONCORE.fields_by_name['plumChallengeExit'].message_type = _PLUMCHALLENGEEXIT
_ACTIONCORE.fields_by_name['plumResponseChallengeExit'].message_type = _PLUMRESPONSECHALLENGEEXIT
_ACTIONCORE.fields_by_name['plumFinalizeExit'].message_type = _PLUMFINALIZEEXIT
_ACTIONCORE.fields_by_name['plumSettleDeposit'].message_type = _PLUMSETTLEDEPOSIT
_ACTIONCORE.fields_by_name['plumTransfer'].message_type = _PLUMTRANSFER
_ACTIONCORE.fields_by_name['depositToRewardingFund'].message_type = _DEPOSITTOREWARDINGFUND
_ACTIONCORE.fields_by_name['claimFromRewardingFund'].message_type = _CLAIMFROMREWARDINGFUND
_ACTIONCORE.fields_by_name['grantReward'].message_type = _GRANTREWARD
_ACTIONCORE.fields_by_name['stakeCreate'].message_type = _STAKECREATE
_ACTIONCORE.fields_by_name['stakeUnstake'].message_type = _STAKERECLAIM
_ACTIONCORE.fields_by_name['stakeWithdraw'].message_type = _STAKERECLAIM
_ACTIONCORE.fields_by_name['stakeAddDeposit'].message_type = _STAKEADDDEPOSIT
_ACTIONCORE.fields_by_name['stakeRestake'].message_type = _STAKERESTAKE
_ACTIONCORE.fields_by_name['stakeChangeCandidate'].message_type = _STAKECHANGECANDIDATE
_ACTIONCORE.fields_by_name['stakeTransferOwnership'].message_type = _STAKETRANSFEROWNERSHIP
_ACTIONCORE.fields_by_name['candidateRegister'].message_type = _CANDIDATEREGISTER
_ACTIONCORE.fields_by_name['candidateUpdate'].message_type = _CANDIDATEBASICINFO
_ACTIONCORE.fields_by_name['putPollResult'].message_type = _PUTPOLLRESULT
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['transfer'])
_ACTIONCORE.fields_by_name['transfer'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['execution'])
_ACTIONCORE.fields_by_name['execution'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['startSubChain'])
_ACTIONCORE.fields_by_name['startSubChain'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stopSubChain'])
_ACTIONCORE.fields_by_name['stopSubChain'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['putBlock'])
_ACTIONCORE.fields_by_name['putBlock'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['createDeposit'])
_ACTIONCORE.fields_by_name['createDeposit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['settleDeposit'])
_ACTIONCORE.fields_by_name['settleDeposit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['createPlumChain'])
_ACTIONCORE.fields_by_name['createPlumChain'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['terminatePlumChain'])
_ACTIONCORE.fields_by_name['terminatePlumChain'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumPutBlock'])
_ACTIONCORE.fields_by_name['plumPutBlock'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumCreateDeposit'])
_ACTIONCORE.fields_by_name['plumCreateDeposit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumStartExit'])
_ACTIONCORE.fields_by_name['plumStartExit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumChallengeExit'])
_ACTIONCORE.fields_by_name['plumChallengeExit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumResponseChallengeExit'])
_ACTIONCORE.fields_by_name['plumResponseChallengeExit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumFinalizeExit'])
_ACTIONCORE.fields_by_name['plumFinalizeExit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumSettleDeposit'])
_ACTIONCORE.fields_by_name['plumSettleDeposit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['plumTransfer'])
_ACTIONCORE.fields_by_name['plumTransfer'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['depositToRewardingFund'])
_ACTIONCORE.fields_by_name['depositToRewardingFund'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['claimFromRewardingFund'])
_ACTIONCORE.fields_by_name['claimFromRewardingFund'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['grantReward'])
_ACTIONCORE.fields_by_name['grantReward'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeCreate'])
_ACTIONCORE.fields_by_name['stakeCreate'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeUnstake'])
_ACTIONCORE.fields_by_name['stakeUnstake'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeWithdraw'])
_ACTIONCORE.fields_by_name['stakeWithdraw'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeAddDeposit'])
_ACTIONCORE.fields_by_name['stakeAddDeposit'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeRestake'])
_ACTIONCORE.fields_by_name['stakeRestake'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeChangeCandidate'])
_ACTIONCORE.fields_by_name['stakeChangeCandidate'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['stakeTransferOwnership'])
_ACTIONCORE.fields_by_name['stakeTransferOwnership'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['candidateRegister'])
_ACTIONCORE.fields_by_name['candidateRegister'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['candidateUpdate'])
_ACTIONCORE.fields_by_name['candidateUpdate'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTIONCORE.oneofs_by_name['action'].fields.append(
  _ACTIONCORE.fields_by_name['putPollResult'])
_ACTIONCORE.fields_by_name['putPollResult'].containing_oneof = _ACTIONCORE.oneofs_by_name['action']
_ACTION.fields_by_name['core'].message_type = _ACTIONCORE
_RECEIPT.fields_by_name['logs'].message_type = _LOG
_LOGS.fields_by_name['logs'].message_type = _LOG
_EVMTRANSFERLIST.fields_by_name['evmTransfers'].message_type = _EVMTRANSFER
_ACTIONEVMTRANSFER.fields_by_name['evmTransfers'].message_type = _EVMTRANSFER
_BLOCKEVMTRANSFER.fields_by_name['actionEvmTransfers'].message_type = _ACTIONEVMTRANSFER
_GRANTREWARD.fields_by_name['type'].enum_type = _REWARDTYPE
DESCRIPTOR.message_types_by_name['Transfer'] = _TRANSFER
DESCRIPTOR.message_types_by_name['Candidate'] = _CANDIDATE
DESCRIPTOR.message_types_by_name['CandidateList'] = _CANDIDATELIST
DESCRIPTOR.message_types_by_name['PutPollResult'] = _PUTPOLLRESULT
DESCRIPTOR.message_types_by_name['Execution'] = _EXECUTION
DESCRIPTOR.message_types_by_name['StakeCreate'] = _STAKECREATE
DESCRIPTOR.message_types_by_name['StakeReclaim'] = _STAKERECLAIM
DESCRIPTOR.message_types_by_name['StakeAddDeposit'] = _STAKEADDDEPOSIT
DESCRIPTOR.message_types_by_name['StakeRestake'] = _STAKERESTAKE
DESCRIPTOR.message_types_by_name['StakeChangeCandidate'] = _STAKECHANGECANDIDATE
DESCRIPTOR.message_types_by_name['StakeTransferOwnership'] = _STAKETRANSFEROWNERSHIP
DESCRIPTOR.message_types_by_name['CandidateBasicInfo'] = _CANDIDATEBASICINFO
DESCRIPTOR.message_types_by_name['CandidateRegister'] = _CANDIDATEREGISTER
DESCRIPTOR.message_types_by_name['StartSubChain'] = _STARTSUBCHAIN
DESCRIPTOR.message_types_by_name['StopSubChain'] = _STOPSUBCHAIN
DESCRIPTOR.message_types_by_name['MerkleRoot'] = _MERKLEROOT
DESCRIPTOR.message_types_by_name['PutBlock'] = _PUTBLOCK
DESCRIPTOR.message_types_by_name['CreateDeposit'] = _CREATEDEPOSIT
DESCRIPTOR.message_types_by_name['SettleDeposit'] = _SETTLEDEPOSIT
DESCRIPTOR.message_types_by_name['CreatePlumChain'] = _CREATEPLUMCHAIN
DESCRIPTOR.message_types_by_name['TerminatePlumChain'] = _TERMINATEPLUMCHAIN
DESCRIPTOR.message_types_by_name['PlumPutBlock'] = _PLUMPUTBLOCK
DESCRIPTOR.message_types_by_name['PlumCreateDeposit'] = _PLUMCREATEDEPOSIT
DESCRIPTOR.message_types_by_name['PlumStartExit'] = _PLUMSTARTEXIT
DESCRIPTOR.message_types_by_name['PlumChallengeExit'] = _PLUMCHALLENGEEXIT
DESCRIPTOR.message_types_by_name['PlumResponseChallengeExit'] = _PLUMRESPONSECHALLENGEEXIT
DESCRIPTOR.message_types_by_name['PlumFinalizeExit'] = _PLUMFINALIZEEXIT
DESCRIPTOR.message_types_by_name['PlumSettleDeposit'] = _PLUMSETTLEDEPOSIT
DESCRIPTOR.message_types_by_name['PlumTransfer'] = _PLUMTRANSFER
DESCRIPTOR.message_types_by_name['ActionCore'] = _ACTIONCORE
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['Receipt'] = _RECEIPT
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['Logs'] = _LOGS
DESCRIPTOR.message_types_by_name['EvmTransfer'] = _EVMTRANSFER
DESCRIPTOR.message_types_by_name['EvmTransferList'] = _EVMTRANSFERLIST
DESCRIPTOR.message_types_by_name['ActionEvmTransfer'] = _ACTIONEVMTRANSFER
DESCRIPTOR.message_types_by_name['BlockEvmTransfer'] = _BLOCKEVMTRANSFER
DESCRIPTOR.message_types_by_name['DepositToRewardingFund'] = _DEPOSITTOREWARDINGFUND
DESCRIPTOR.message_types_by_name['ClaimFromRewardingFund'] = _CLAIMFROMREWARDINGFUND
DESCRIPTOR.message_types_by_name['GrantReward'] = _GRANTREWARD
DESCRIPTOR.enum_types_by_name['RewardType'] = _REWARDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transfer = _reflection.GeneratedProtocolMessageType('Transfer', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Transfer)
  })
_sym_db.RegisterMessage(Transfer)

Candidate = _reflection.GeneratedProtocolMessageType('Candidate', (_message.Message,), {
  'DESCRIPTOR' : _CANDIDATE,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Candidate)
  })
_sym_db.RegisterMessage(Candidate)

CandidateList = _reflection.GeneratedProtocolMessageType('CandidateList', (_message.Message,), {
  'DESCRIPTOR' : _CANDIDATELIST,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.CandidateList)
  })
_sym_db.RegisterMessage(CandidateList)

PutPollResult = _reflection.GeneratedProtocolMessageType('PutPollResult', (_message.Message,), {
  'DESCRIPTOR' : _PUTPOLLRESULT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PutPollResult)
  })
_sym_db.RegisterMessage(PutPollResult)

Execution = _reflection.GeneratedProtocolMessageType('Execution', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTION,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Execution)
  })
_sym_db.RegisterMessage(Execution)

StakeCreate = _reflection.GeneratedProtocolMessageType('StakeCreate', (_message.Message,), {
  'DESCRIPTOR' : _STAKECREATE,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeCreate)
  })
_sym_db.RegisterMessage(StakeCreate)

StakeReclaim = _reflection.GeneratedProtocolMessageType('StakeReclaim', (_message.Message,), {
  'DESCRIPTOR' : _STAKERECLAIM,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeReclaim)
  })
_sym_db.RegisterMessage(StakeReclaim)

StakeAddDeposit = _reflection.GeneratedProtocolMessageType('StakeAddDeposit', (_message.Message,), {
  'DESCRIPTOR' : _STAKEADDDEPOSIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeAddDeposit)
  })
_sym_db.RegisterMessage(StakeAddDeposit)

StakeRestake = _reflection.GeneratedProtocolMessageType('StakeRestake', (_message.Message,), {
  'DESCRIPTOR' : _STAKERESTAKE,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeRestake)
  })
_sym_db.RegisterMessage(StakeRestake)

StakeChangeCandidate = _reflection.GeneratedProtocolMessageType('StakeChangeCandidate', (_message.Message,), {
  'DESCRIPTOR' : _STAKECHANGECANDIDATE,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeChangeCandidate)
  })
_sym_db.RegisterMessage(StakeChangeCandidate)

StakeTransferOwnership = _reflection.GeneratedProtocolMessageType('StakeTransferOwnership', (_message.Message,), {
  'DESCRIPTOR' : _STAKETRANSFEROWNERSHIP,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StakeTransferOwnership)
  })
_sym_db.RegisterMessage(StakeTransferOwnership)

CandidateBasicInfo = _reflection.GeneratedProtocolMessageType('CandidateBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _CANDIDATEBASICINFO,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.CandidateBasicInfo)
  })
_sym_db.RegisterMessage(CandidateBasicInfo)

CandidateRegister = _reflection.GeneratedProtocolMessageType('CandidateRegister', (_message.Message,), {
  'DESCRIPTOR' : _CANDIDATEREGISTER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.CandidateRegister)
  })
_sym_db.RegisterMessage(CandidateRegister)

StartSubChain = _reflection.GeneratedProtocolMessageType('StartSubChain', (_message.Message,), {
  'DESCRIPTOR' : _STARTSUBCHAIN,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StartSubChain)
  })
_sym_db.RegisterMessage(StartSubChain)

StopSubChain = _reflection.GeneratedProtocolMessageType('StopSubChain', (_message.Message,), {
  'DESCRIPTOR' : _STOPSUBCHAIN,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.StopSubChain)
  })
_sym_db.RegisterMessage(StopSubChain)

MerkleRoot = _reflection.GeneratedProtocolMessageType('MerkleRoot', (_message.Message,), {
  'DESCRIPTOR' : _MERKLEROOT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.MerkleRoot)
  })
_sym_db.RegisterMessage(MerkleRoot)

PutBlock = _reflection.GeneratedProtocolMessageType('PutBlock', (_message.Message,), {
  'DESCRIPTOR' : _PUTBLOCK,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PutBlock)
  })
_sym_db.RegisterMessage(PutBlock)

CreateDeposit = _reflection.GeneratedProtocolMessageType('CreateDeposit', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDEPOSIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.CreateDeposit)
  })
_sym_db.RegisterMessage(CreateDeposit)

SettleDeposit = _reflection.GeneratedProtocolMessageType('SettleDeposit', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEDEPOSIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.SettleDeposit)
  })
_sym_db.RegisterMessage(SettleDeposit)

CreatePlumChain = _reflection.GeneratedProtocolMessageType('CreatePlumChain', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLUMCHAIN,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.CreatePlumChain)
  })
_sym_db.RegisterMessage(CreatePlumChain)

TerminatePlumChain = _reflection.GeneratedProtocolMessageType('TerminatePlumChain', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATEPLUMCHAIN,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.TerminatePlumChain)
  })
_sym_db.RegisterMessage(TerminatePlumChain)

PlumPutBlock = _reflection.GeneratedProtocolMessageType('PlumPutBlock', (_message.Message,), {

  'RootsEntry' : _reflection.GeneratedProtocolMessageType('RootsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLUMPUTBLOCK_ROOTSENTRY,
    '__module__' : 'proto.types.action_pb2'
    # @@protoc_insertion_point(class_scope:iotextypes.PlumPutBlock.RootsEntry)
    })
  ,
  'DESCRIPTOR' : _PLUMPUTBLOCK,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumPutBlock)
  })
_sym_db.RegisterMessage(PlumPutBlock)
_sym_db.RegisterMessage(PlumPutBlock.RootsEntry)

PlumCreateDeposit = _reflection.GeneratedProtocolMessageType('PlumCreateDeposit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMCREATEDEPOSIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumCreateDeposit)
  })
_sym_db.RegisterMessage(PlumCreateDeposit)

PlumStartExit = _reflection.GeneratedProtocolMessageType('PlumStartExit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMSTARTEXIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumStartExit)
  })
_sym_db.RegisterMessage(PlumStartExit)

PlumChallengeExit = _reflection.GeneratedProtocolMessageType('PlumChallengeExit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMCHALLENGEEXIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumChallengeExit)
  })
_sym_db.RegisterMessage(PlumChallengeExit)

PlumResponseChallengeExit = _reflection.GeneratedProtocolMessageType('PlumResponseChallengeExit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMRESPONSECHALLENGEEXIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumResponseChallengeExit)
  })
_sym_db.RegisterMessage(PlumResponseChallengeExit)

PlumFinalizeExit = _reflection.GeneratedProtocolMessageType('PlumFinalizeExit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMFINALIZEEXIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumFinalizeExit)
  })
_sym_db.RegisterMessage(PlumFinalizeExit)

PlumSettleDeposit = _reflection.GeneratedProtocolMessageType('PlumSettleDeposit', (_message.Message,), {
  'DESCRIPTOR' : _PLUMSETTLEDEPOSIT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumSettleDeposit)
  })
_sym_db.RegisterMessage(PlumSettleDeposit)

PlumTransfer = _reflection.GeneratedProtocolMessageType('PlumTransfer', (_message.Message,), {
  'DESCRIPTOR' : _PLUMTRANSFER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.PlumTransfer)
  })
_sym_db.RegisterMessage(PlumTransfer)

ActionCore = _reflection.GeneratedProtocolMessageType('ActionCore', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONCORE,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.ActionCore)
  })
_sym_db.RegisterMessage(ActionCore)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {
  'DESCRIPTOR' : _ACTION,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Action)
  })
_sym_db.RegisterMessage(Action)

Receipt = _reflection.GeneratedProtocolMessageType('Receipt', (_message.Message,), {
  'DESCRIPTOR' : _RECEIPT,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Receipt)
  })
_sym_db.RegisterMessage(Receipt)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Log)
  })
_sym_db.RegisterMessage(Log)

Logs = _reflection.GeneratedProtocolMessageType('Logs', (_message.Message,), {
  'DESCRIPTOR' : _LOGS,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Logs)
  })
_sym_db.RegisterMessage(Logs)

EvmTransfer = _reflection.GeneratedProtocolMessageType('EvmTransfer', (_message.Message,), {
  'DESCRIPTOR' : _EVMTRANSFER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.EvmTransfer)
  })
_sym_db.RegisterMessage(EvmTransfer)

EvmTransferList = _reflection.GeneratedProtocolMessageType('EvmTransferList', (_message.Message,), {
  'DESCRIPTOR' : _EVMTRANSFERLIST,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.EvmTransferList)
  })
_sym_db.RegisterMessage(EvmTransferList)

ActionEvmTransfer = _reflection.GeneratedProtocolMessageType('ActionEvmTransfer', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONEVMTRANSFER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.ActionEvmTransfer)
  })
_sym_db.RegisterMessage(ActionEvmTransfer)

BlockEvmTransfer = _reflection.GeneratedProtocolMessageType('BlockEvmTransfer', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKEVMTRANSFER,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockEvmTransfer)
  })
_sym_db.RegisterMessage(BlockEvmTransfer)

DepositToRewardingFund = _reflection.GeneratedProtocolMessageType('DepositToRewardingFund', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITTOREWARDINGFUND,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.DepositToRewardingFund)
  })
_sym_db.RegisterMessage(DepositToRewardingFund)

ClaimFromRewardingFund = _reflection.GeneratedProtocolMessageType('ClaimFromRewardingFund', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMFROMREWARDINGFUND,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.ClaimFromRewardingFund)
  })
_sym_db.RegisterMessage(ClaimFromRewardingFund)

GrantReward = _reflection.GeneratedProtocolMessageType('GrantReward', (_message.Message,), {
  'DESCRIPTOR' : _GRANTREWARD,
  '__module__' : 'proto.types.action_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.GrantReward)
  })
_sym_db.RegisterMessage(GrantReward)


DESCRIPTOR._options = None
_PLUMPUTBLOCK_ROOTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# MIT License
#
# Copyright (c) 2020 Worawat Wijarn worawat.wijarn@gmail.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import click

from iotexetl.cli.export_blocks import export_blocks
from iotexetl.cli.export_transaction_logs import export_transaction_logs
from iotexetl.cli.export_logs import export_logs
from iotexetl.cli.get_block_range_for_date import get_block_range_for_date
from iotexetl.cli.stream import stream


@click.group()
@click.version_option(version='0.0.9')
@click.pass_context
def cli(ctx):
    pass


# export
cli.add_command(export_blocks, "export_blocks")
cli.add_command(export_transaction_logs, "export_transaction_logs")
cli.add_command(export_logs, "export_logs")

# streaming
cli.add_command(stream, "stream")

# utils
cli.add_command(get_block_range_for_date, "get_block_range_for_date")


from iotexetl.utils import string_utils


def map_transaction_logs(raw_block, block_transaction_log):
    for log in block_transaction_log.transactionLogs.logs:
        for index, transaction in enumerate(log.transactions):
            yield {
                'type': 'transaction_log',
                'transaction_log_type': transaction.type,
                'height': block_transaction_log.blockIdentifier.height,
                'action_hash': log.actionHash.hex(),
                'index': index,
                'topic': string_utils.base64_string(transaction.topic),
                'amount': string_utils.to_int(transaction.amount),
                'sender': transaction.sender,
                'recipient': transaction.recipient,
                'timestamp': raw_block.block.header.core.timestamp.ToJsonString(),
            }